---
title: '나이스페이먼츠_허브형 간편결제 추가방법 '
category: 결제서비스 (채널설정 및 이용안내) > 결제유형 > 간편결제
tags:
  - 허브형
  - 간편결제
pgCompanies:
  - 나이스페이먼츠
searchTags:
  - 허브형 간편결제
  - 나이스페이먼츠 간편결제
  - 나이스페이먼츠
  - 간편결제
  - 허브형
datetime: 2024-09-24T05:40:12.616Z
---

<Callout content="나이스페이먼츠에 이미 가입되어 있으신 경우, 
나이스페이먼츠측에 간편결제 추가계약 절차가 필요 합니다!" />

### 나이스페이먼츠 추가계약 절차

- 나이스페이먼츠 계약부서(TEL : 1661-7335 > 3)를 통해, 간편결제 서비스 추가 계약 요청
- 나이스페이먼츠 서비스 추가 계약/심사 진행
  \- 간편결제용 MID 발급을 위한 \[아이디 추가 신청서] 및 \[간편결제 신청서] 접수 필요
  \- 별도 심사 후 이용가능, 일부 유의업종 서비스 제공 불가
- 나이스페이먼츠 간편결제 서비스 입점 심사 진행 및 가맹점 심사 결과 안내
- 나이스페이먼츠 간편결제 서비스 사용 설정
- 서브몰 심사 요청(원천사(간편결제사) 심사 요청)
- 서브몰 심사 완료

추가 계약 요청 후 나이스페이먼츠 담당자가 계약절차 및 계약서류 안내드릴 예정입니다. (약 3영업일 소요)

- [허브형 간편결제 이용 방법 보러가기 ↗](https://help-center-portone.vercel.app/content/hub-service-fee)
- [나이스페이먼츠\_간편결제 연동 방법 ↗](https://help.portone.io/content/nice-easypay-hub-fee)

<Callout title="참고사항" content="나이스페이먼츠는 일반결제와 허브형 간편결제용 MID가 별도 발급되므로, 추가 설정하시어 pg파라미터에 MID를 지정하여 요청하도록 구현 부탁 드립니다." />
